
.. _RefMonitorFunctions:

monitorfunctions
================
The :code:`monitorfunctions` module provides various functions related to
monitors and windows. Windows can be positioned and resized on a monitor, or be moved
to another monitor.

Windows only.

.. automodule:: dtactions.monitorfunctions
   :members:
